/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.application.list;

import com.liferay.portal.kernel.model.Group;

import javax.servlet.http.HttpServletRequest;

/**
 * Provides an interface that defines how a <code>Group</code> (in
 * <code>portal-kernel</code>) associated with a servlet request is stored and
 * retrieved.
 *
 * @author Julio Camarero
 */
public interface GroupProvider {

	/**
	 * Returns the <code>Group</code> associated with the request.
	 *
	 * @param  request the servlet request used to retrieve the group
	 * @return the <code>Group</code> associated with the request
	 */
	public Group getGroup(HttpServletRequest request);

	/**
	 * Sets the <code>Group</code> to associate with the request.
	 *
	 * @param request the servlet request used to associate the
	 *        <code>Group</code>
	 * @param group the <code>Group</code> to associate with the request
	 */
	public void setGroup(HttpServletRequest request, Group group);

}